from .algos import WelfordAlg

def read_stats(path, pulseIds, user_mask=None):
    import numpy as np
    import xarray as xr
    from h5py import File

    with File(path) as stats:
        mean_pixelcell = []
        for mod in range(16):
            summed= np.zeros((len(pulseIds),512,128))
            counts = 0
            for file in stats[f'mod{mod:02d}'].keys():
                _cnt = np.array(stats[f'mod{mod:02d}/'+file+'/count'])
                summed += np.array(stats[f'mod{mod:02d}/'+file+'/mean/'])*_cnt
                counts += _cnt
            mean_pixelcell.append(summed/counts)

        mean_pixelcell = xr.DataArray(
            data = np.stack(mean_pixelcell),
            dims = ['module','pulseId','dim_0','dim_1'],
            coords = dict(
                module = np.arange(16),
                pulseId = pulseIds,
                dim_0 = np.arange(512),
                dim_1 = np.arange(128))).transpose('pulseId','module','dim_0','dim_1')

    if user_mask is not None:
        mean_pixelcell = mean_pixelcell.where(~user_mask[None, :, :, :])

    return mean_pixelcell
