import cython

@cython.boundscheck(False)
@cython.wraparound(False)  
def welford (float[:,:,::1] x,
             float[:,:,::1] avg,
             float[:,:,::1] var,
             float[:,:,::1] alpha):

    cdef int size = avg.shape[0] * avg.shape[1] * avg.shape[2]
    
    _wf(&x[0,0,0], &avg[0,0,0], &var[0,0,0], &alpha[0,0,0], size)
                   
    
@cython.boundscheck(False)
@cython.wraparound(False)    
cdef _wf(float* x,
         float* avg,
         float* var,
         float* alpha, 
         int    size):
    cdef float delta, al, oneNegAl# = 1 - alpha
    cdef int i
    
    
    for i in range(size):
        al = alpha[i]
        oneNegAl = 1 - al
        delta = x[i] - avg[i]
        avg[i] += al * delta
        var[i] = oneNegAl * (var[i] + al * delta * delta)
    
    

