import numpy as np

from karabo.bound import (
    NODE_ELEMENT,
    DOUBLE_ELEMENT
)

from calng.correction_addons.base_addon import BaseCorrectionAddon


class Photonizer(BaseCorrectionAddon):
    def __init__(self, config):
        global cupy
        import cupy

        self._photon_energy = config.get("photonEnergy")

    @staticmethod
    def extend_device_schema(schema, prefix):
        (
            DOUBLE_ELEMENT(schema)
            .key(f"{prefix}.photonEnergy")
            .tags("managed")
            .assignmentOptional()
            .defaultValue(8.0)
            .reconfigurable()
            .commit(),
        )

    def reconfigure(self, changed_config):
        if changed_config.has("photonEnergy"):
            self._photon_energy = changed_config["photonEnergy"]

    def post_correction(self, data, cell_table, pulse_table, output_hash):
        data /= self._photon_energy
        np.around(data, out=data)

    def post_reshape(self, data, cell_table, pulse_table, output_hash):
        print(output_hash["header"].keys())
